#[non_exhaustive]
pub enum Request<'a> { Motion { time: u32, dx: f64, dy: f64, }, MotionAbsolute { time: u32, x: u32, y: u32, x_extent: u32, y_extent: u32, }, Button { time: u32, button: u32, state: WEnum<ButtonState>, }, Axis { time: u32, axis: WEnum<Axis>, value: f64, }, Frame, AxisSource { axis_source: WEnum<AxisSource>, }, AxisStop { time: u32, axis: WEnum<Axis>, }, AxisDiscrete { time: u32, axis: WEnum<Axis>, value: f64, discrete: i32, }, Destroy, }
Available on crate feature wayland and Linux only.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Motion

pointer relative motion event

The pointer has moved by a relative amount to the previous request.

Values are in the global compositor space.

Fields

time: u32

timestamp with millisecond granularity

dx: f64

displacement on the x-axis

dy: f64

displacement on the y-axis



MotionAbsolute

pointer absolute motion event

The pointer has moved in an absolute coordinate frame.

Value of x can range from 0 to x_extent, value of y can range from 0 to y_extent.

Fields

time: u32

timestamp with millisecond granularity

x: u32

position on the x-axis

y: u32

position on the y-axis

x_extent: u32

extent of the x-axis

y_extent: u32

extent of the y-axis



Button

button event

A button was pressed or released.

Fields

time: u32

timestamp with millisecond granularity

button: u32

button that produced the event

state: WEnum<ButtonState>

physical state of the button



Axis

axis event

Scroll and other axis requests.

Fields

time: u32

timestamp with millisecond granularity

axis: WEnum<Axis>

axis type

value: f64

length of vector in touchpad coordinates



Frame

end of a pointer event sequence

Indicates the set of events that logically belong together.



AxisSource

axis source event

Source information for scroll and other axis.

Fields

axis_source: WEnum<AxisSource>

source of the axis event



AxisStop

axis stop event

Stop notification for scroll and other axes.

Fields

time: u32

timestamp with millisecond granularity

axis: WEnum<Axis>

the axis stopped with this event



AxisDiscrete

axis click event

Discrete step information for scroll and other axes.

This event allows the client to extend data normally sent using the axis event with discrete value.

Fields

time: u32

timestamp with millisecond granularity

axis: WEnum<Axis>

axis type

value: f64

length of vector in touchpad coordinates

discrete: i32

number of steps



Destroy

destroy the virtual pointer object

This is a destructor, once sent this object cannot be used any longer.

Implementations



impl<'a> Request<'a>

pub fn opcode(&self) -> u16

Get the opcode number of this message