Struct ZwlrVirtualPointerV1

pub struct ZwlrVirtualPointerV1 { /* private fields */ }
Available on crate feature wayland and Linux only.
virtual pointer

This protocol allows clients to emulate a physical pointer device. The requests are mostly mirror opposites of those specified in wl_pointer.

This interface has no events.

Implementations



impl ZwlrVirtualPointerV1

pub fn motion(&self, time: u32, dx: f64, dy: f64)

pointer relative motion event

The pointer has moved by a relative amount to the previous request.

Values are in the global compositor space.

pub fn motion_absolute( &self, time: u32, x: u32, y: u32, x_extent: u32, y_extent: u32, )

pointer absolute motion event

The pointer has moved in an absolute coordinate frame.

Value of x can range from 0 to x_extent, value of y can range from 0 to y_extent.

pub fn button(&self, time: u32, button: u32, state: ButtonState)

button event

A button was pressed or released.

pub fn axis(&self, time: u32, axis: Axis, value: f64)

axis event

Scroll and other axis requests.

pub fn frame(&self)

end of a pointer event sequence

Indicates the set of events that logically belong together.

pub fn axis_source(&self, axis_source: AxisSource)

axis source event

Source information for scroll and other axis.

pub fn axis_stop(&self, time: u32, axis: Axis)

axis stop event

Stop notification for scroll and other axes.

pub fn axis_discrete(&self, time: u32, axis: Axis, value: f64, discrete: i32)

axis click event

Discrete step information for scroll and other axes.

This event allows the client to extend data normally sent using the axis event with discrete value.

pub fn destroy(&self)

destroy the virtual pointer object